@@ -1,8 +1,9 @@
 ## File Name: dbct_scaled_mdmb_regression_wrapper.R
-## File Version: 0.01
+## File Version: 0.03
 
 
 dbct_scaled_mdmb_regression_wrapper <- function(probit=FALSE, ...)
 {
-    return( dbct_scaled(...) )
+    res <- dbct_scaled(...)
+    return(res)
 }
