@@ -1,5 +1,5 @@
 ## File Name: frm_mlreg_wrapper_ml_mcmc.R
-## File Version: 0.17
+## File Version: 0.282
 
 frm_mlreg_wrapper_ml_mcmc <- function( data, formula, weights=NULL,
     sample_missings=TRUE, ...)
@@ -8,6 +8,10 @@ frm_mlreg_wrapper_ml_mcmc <- function( data, formula, weights=NULL,
     if (sample_missings){
         data <- mdmb_sample_missings(data=data, vars=vars)
     }
-    res <- miceadds::ml_mcmc( formula=formula, data=data, ...)
+    args <- list( formula=formula, data=data, ...)
+    if ( ! ( "inits_lme4" %in% names(args) ) ){
+        args$inits_lme4 <- FALSE
+    }
+    res <- do.call( what=miceadds::ml_mcmc, args=args)
     return(res)
 }
